@@ -44,7 +44,7 @@ impl Application for DemoWindow {
         file.add_separator();
         new.add_menuitem(project);
         menubar.add_menu(file);
-        frame.set_menu(menubar);
+        frame.clone().set_menu(menubar);
         frame.show();
     }
 
