@@ -140,5 +140,7 @@ pub const FC_ENABLE_HELP:winapi::shared::minwindef::DWORD = winapi::um::commdlg:
 
 
 
-#[cfg(windows)]
-pub const WT_BUTTON:WidgetStyle = "BUTTON\0";
\ No newline at end of file
+#[deprecated(since="0.15.2", note="Please use the respective widget structure")]
+pub const WT_BUTTON:WidgetStyle = "BUTTON\0";
+#[deprecated(since="0.15.2", note="Please use the respective widget structure")]
+pub const WT_TEXTEDIT:WidgetStyle = "EDIT\0";
\ No newline at end of file
