@@ -47,7 +47,7 @@ impl MenuBar {
 
     pub fn add_menu(&self,item: MenuItem) {
         use gtk::prelude::*;
-        self.menu.append(Some(item.get_title()),Some("win"));
+        self.menu.append_item(&item.get_menu());
     }
 
     pub fn get_menu(self) -> gtk::gio::Menu {
