@@ -36,4 +36,30 @@ impl TextEdit {
             ShowWindow(self.handle,SW_SHOWNORMAL);
         }
     }
+}
+
+#[cfg(unix)]
+pub struct TextEdit {
+    pub handle: gtk::TextView
+}
+
+#[cfg(unix)]
+impl TextEdit {
+    pub fn new(attributes: Attributes,frame: &Frame) -> Self {
+        use gtk::prelude::*;
+        let handle = gtk::TextView::new();
+        handle.set_height_request(attributes.height/10);
+        handle.set_width_request(attributes.width/10);
+        handle.set_margin_top(attributes.y);
+        handle.set_margin_start(attributes.x);
+        frame.get_window().add(&handle);
+        Self {
+            handle
+        }
+    }
+
+    pub fn show(&self) {
+        use gtk::prelude::*;
+        self.handle.show();
+    }
 }
\ No newline at end of file
